summaryrefslogtreecommitdiffstats
path: root/src/usr/secureboot/base/service.C
diff options
context:
space:
mode:
authorStephen Cprek <smcprek@us.ibm.com>2017-02-23 14:44:00 -0600
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-03-08 17:57:03 -0500
commit2e65c884bc76759a6010249036c57c02e1516a36 (patch)
treeab1a5a9f06444c27107513fc0a9cc32564c85f10 /src/usr/secureboot/base/service.C
parente7b1c8518656917f5202f069165d21aafd7a88ad (diff)
downloadtalos-hostboot-2e65c884bc76759a6010249036c57c02e1516a36.tar.gz
talos-hostboot-2e65c884bc76759a6010249036c57c02e1516a36.zip
Rename SecureROM to SecureRomManager
Change-Id: I839daf3fc44e3459a9c6c147703fd671c5ec79a8 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/36971 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Nicholas E. Bofferding <bofferdn@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Reviewed-by: Michael Baiocchi <mbaiocch@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/secureboot/base/service.C')
-rw-r--r--src/usr/secureboot/base/service.C4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/usr/secureboot/base/service.C b/src/usr/secureboot/base/service.C
index 54b7d7fb7..05a29acc3 100644
--- a/src/usr/secureboot/base/service.C
+++ b/src/usr/secureboot/base/service.C
@@ -75,13 +75,13 @@ void* initializeBase(void* unused)
assert(0 == mm_extend(MM_EXTEND_PARTIAL_CACHE));
// Don't extend more than 1/2 cache in VPO as fake PNOR is there
// Don't enable SecureROM in VPO
#ifndef CONFIG_P9_VPO_COMPILE
// Run dcbz on the entire 10MB cache
assert(0 == mm_extend(MM_EXTEND_FULL_CACHE));
// Initialize the Secure ROM
- l_errl = initializeSecureROM();
+ l_errl = initializeSecureRomManager();
if (l_errl)
{
break;
@@ -75,13 +75,13 @@ void* initializeBase(void* unused)
assert(0 == mm_extend(MM_EXTEND_PARTIAL_CACHE));
// Don't extend more than 1/2 cache in VPO as fake PNOR is there
- // Don't enable SecureROM in VPO
+ // Don't enable SecureRomManager in VPO
#ifndef CONFIG_P9_VPO_COMPILE
// Run dcbz on the entire 10MB cache
OpenPOWER on IntegriCloud